score

# XMLRésuméLibrary: User Guide

resumes | Element Reference | skill

## Name

score — The score earned in a GPA

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `score` element contains the GPA score that a person has earned.

### Parents

`score` may be contained in these elements: `gpa`

## See Also

`possible`.

## Examples

For examples, see `gpa`.

resumes | Element Reference | skill